normalize method
void
normalize()
Normalizes the crop rect to fit inside the transformed image quad.
Implementation
void normalize() {
data = data.copyWith(cropRect: normalizeImpl());
}
Normalizes the crop rect to fit inside the transformed image quad.
void normalize() {
data = data.copyWith(cropRect: normalizeImpl());
}