CroppableImageData class

Annotations

Constructors

CroppableImageData({required Size imageSize, required Rect cropRect, required CropShape cropShape, required BaseTransformations baseTransformations, required Matrix4 imageTransform, required Matrix4 currentImageTransform})
const
CroppableImageData.initial({required Size imageSize, required CropShape cropShape})
CroppableImageData.initialWithCropPathFn({required Size imageSize, required CropShapeFn cropPathFn})

Properties

baseTransformations BaseTransformations
The "base" transformation applied to the image.
final
cropAabb Aabb2
An axis-aligned bounding box of the crop area.
no setter
cropRect Rect
The rectangle containing the crop area.
final
cropShape CropShape
The shape of the crop area.
final
currentImageTransform Matrix4
The current in-progress transformation applied to the image.
final
hashCode int
The hash code for this object.
no setterinherited
imageSize Size
The size of the image to be cropped.
final
imageTransform Matrix4
The transformation applied to the image.
final
inverseImageTransform Matrix4
The inverse of imageTransform.
no setter
isNormalized bool
Whether the crop area is normalized.
no setter
originalImageQuad Quad2
The original quad of the image, before any transformations are applied.
no setter
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
totalImageTransform Matrix4
The total transformation applied to the image.
no setter
transformedImageQuad Quad2
The transformed quad of the image.
no setter
translatedBaseTransformations Matrix4
Returns the base transformation matrix, translated to the center of the image.
no setter

Methods

copyWith({Size? imageSize, Rect? cropRect, CropShape? cropShape, BaseTransformations? baseTransformations, Matrix4? imageTransform, Matrix4? currentImageTransform}) CroppableImageData
Copies this CroppableImageData with the given parameters.
copyWithProperCropShape({Size? imageSize, Rect? cropRect, BaseTransformations? baseTransformations, Matrix4? imageTransform, Matrix4? currentImageTransform, required CropShapeFn cropShapeFn}) CroppableImageData
Copies this CroppableImageData with the given parameters and automatically sets the proper crop shape.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
translateTransformation(Matrix4 transformation) Matrix4
Translates the given transformation to the center of the image.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromImageProvider(ImageProvider<Object> imageProvider, {CropShapeFn cropPathFn = aabbCropShapeFn}) Future<CroppableImageData>
lerp(CroppableImageData? a, CroppableImageData? b, double t) CroppableImageData?
Linearly interpolates between two CroppableImageDatas.